## 期货主力与连续合约

接口：fut_mapping

描述：获取期货主力（或连续）合约与月合约映射数据

限量：单次最大2000条，总量不限制

积分：用户需要至少2000积分才可以调取，未来可能调整积分，请尽可能多积累积分。具体请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 合约代码 |
| trade_date | str | N | 交易日期(YYYYMMDD格式，下同) |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 连续合约代码 |
| trade_date | str | Y | 起始日期 |
| mapping_ts_code | str | Y | 期货合约代码 |

接口示例

```python
pro = ts.pro_api()

#获取主力合约TF.CFX每日对应的月合约
df = pro.fut_mapping(ts_code='TF.CFX')
```

数据示例

```python
ts_code trade_date mapping_ts_code
0     TF.CFX   20190823      TF1912.CFX
```